#!/bin/sh
#   Copyright (c) 2010 digitalSTROM.org, Zurich, Switzerland
#
#   Author: Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
#
#   This file is part of digitalSTROM Server.
#
#   netinfo.sh is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   netinfo.sh is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this file. If not, see <http://www.gnu.org/licenses/>.

#   Note: when called with "upgrade", "addon-upgrade" or "addon-install" 
#   parameter, the "update" command is always executed first.

. ../cgi-bin/errlib.sh

export PATH=/usr/local/bin:/usr/bin:/bin:/usr/local/sbin:/usr/sbin:/sbin
export SHELL=/bin/sh

LOCKFILE="/var/lock/systemupdate"
LOGDIR="/var/log/dss11-websetup"
mkdir -p $LOGDIR 
UPDATE_CODE="$LOGDIR/last-update-code-dsmfw.txt"
UPDATE_MESSAGE="$LOGDIR/last-update-msg-dsmfw.txt"

CMD=perform-dsm-upgrade

if [[ ! -x /usr/bin/perform-dsm-upgrade ]]; then
    echo "perform-dsm-upgrade script not found" 
    echo "[`date`] command \"$CMD\" end ---------------" >> "$LOGDIR/update.log"
    echo
    exit $ERR_SETUP 
fi

if [[ -e "$LOCKFILE" ]]; then
    echo "Lock file exists, update is in progress..." 
    echo "[`date`] command \"$CMD\" end ---------------"
    exit $ERR_DOWAIT 
fi

# we are good to go
touch "$LOCKFILE"


echo "Stopping dSS"

# stop dss for the time of the dSM update
if [[  -f "/etc/runit/dss/supervise/stat" ]]; then
    if [[ "`cat /etc/runit/dss/supervise/stat`" == "run" ]]; then
        echo "Stopping dSS..."
        sv -w 3 force-stop /etc/runit/dss
        if [[ $? -ne 0 ]]; then
            echo "sv command returned error, killing dSS process"
            killall -9 dss
        else
            sleep 3
        fi
    fi
fi

# safeguard to make sure dSS is really down
if [[ -n "`pidof dss`" ]]; then
    killall -9 dss
    sleep 1
fi

echo "Executing: \"$CMD\""
$CMD
RETCODE="$?"

echo "Starting dSS"
if [[ -f "/etc/runit/dss/supervise/stat" ]]; then
    if [[ "`cat /etc/runit/dss/supervise/stat`" == "down" ]]; then
        echo "Starting dSS..."
        sv up /etc/runit/dss
        if [[ $? -ne 0 ]]; then
            echo "sv command return error, could not start dSS!"
        fi
    fi
fi

if [[ "$RETCODE" -ne "0" ]]; then
    echo "$ERR_UPDATE" > $UPDATE_CODE
    echo "Error when attempting to perform dSM firmware upgrade" > $UPDATE_MESSAGE
    echo "Error when attempting to perform dSM firmware upgrade"
    echo "[`date`] command \"$CMD\" end ---------------"
    echo
    rm -f "$LOCKFILE"
    exit $ERR_UPDATE
fi
echo "[`date`] command \"$CMD\" end ---------------"

rm -f "$LOCKFILE"

echo "$ERR_OK" > $UPDATE_CODE
echo "OK" > $UPDATE_MESSAGE
exit $ERR_OK
